"use strict";

// @ts-check
var fs = require("fs");

var path = require("path");

var arrify = require("arrify");

var has = require("lodash.has");

var readPkgUp = require("read-pkg-up");

var which = require("which");

var _readPkgUp$sync = readPkgUp.sync({
  cwd: fs.realpathSync(process.cwd())
}),
    pkg = _readPkgUp$sync.pkg,
    pkgPath = _readPkgUp$sync.path;

var appDirectory = path.dirname(pkgPath);

var isGdScripts = function () {
  return pkg.name === "gd-scripts";
};
/**
 * @param {string} modName
 * @param {{ executable?: string, cwd?: string }} options
 */


var resolveBin = function (modName, _temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$executable = _ref.executable,
      executable = _ref$executable === void 0 ? modName : _ref$executable,
      _ref$cwd = _ref.cwd,
      cwd = _ref$cwd === void 0 ? process.cwd() : _ref$cwd;

  var pathFromWhich;

  try {
    pathFromWhich = fs.realpathSync(which.sync(executable));
  } catch (_error) {// ignore _error
  }

  try {
    var modPkgPath = require.resolve(`${modName}/package.json`);

    var modPkgDir = path.dirname(modPkgPath);

    var _require = require(modPkgPath),
        bin = _require.bin;

    var binPath = typeof bin === "string" ? bin : bin[executable];
    var fullPathToBin = path.join(modPkgDir, binPath);

    if (fullPathToBin === pathFromWhich) {
      return executable;
    }

    return fullPathToBin.replace(cwd, ".");
  } catch (error) {
    if (pathFromWhich) {
      return executable;
    }

    throw error;
  }
};
/**
 * @param {string[]} p
 */


var fromRoot = function () {
  for (var _len = arguments.length, p = new Array(_len), _key = 0; _key < _len; _key++) {
    p[_key] = arguments[_key];
  }

  return path.join.apply(path, [appDirectory].concat(p));
};
/**
 * @param {string[]} p
 */


var hasFile = function () {
  return fs.existsSync(fromRoot.apply(void 0, arguments));
};
/**
 * @param {any} props
 */


var hasPkgProp = function (props) {
  return arrify(props).some(function (prop) {
    return has(pkg, prop);
  });
};
/**
 * @param {string} pkgProp
 * @returns {function(any): boolean}
 */


var hasPkgSubProp = function (pkgProp) {
  return function (props) {
    return hasPkgProp(arrify(props).map(function (p) {
      return `${pkgProp}.${p}`;
    }));
  };
};

var hasPeerDep = hasPkgSubProp("peerDependencies");
var hasDep = hasPkgSubProp("dependencies");
var hasDevDep = hasPkgSubProp("devDependencies");
/**
 * @param {any} args
 */

var hasAnyDep = function (args) {
  return [hasDep, hasDevDep, hasPeerDep].some(function (fn) {
    return fn(args);
  });
};
/**
 * @param {any} deps
 * @param {any} t
 * @param {any} f
 */


var ifAnyDep = function (deps, t, f) {
  return hasAnyDep(arrify(deps)) ? t : f;
};
/**
 * @param {string} name
 */


var envIsSet = function (name) {
  return process.env.hasOwnProperty(name) && process.env[name] && process.env[name] !== "undefined";
};
/**
 * @param {string} name
 * @param {string} def
 */


var parseEnv = function (name, def) {
  if (envIsSet(name)) {
    try {
      return JSON.parse(
      /** @type {any} */
      process.env[name]);
    } catch (err) {
      return process.env[name];
    }
  }

  return def;
};

module.exports = {
  appDirectory,
  resolveBin,
  fromRoot,
  hasFile,
  hasPkgProp,
  ifAnyDep,
  parseEnv,
  envIsSet,
  isGdScripts
};
//# sourceMappingURL=utils.js.map